# Metamart Fivetran Integration

The Fivetran integration synchronizes metadata from your Fivetran instance into your Metamart data lineage graph.


# Testing

Uses `fastapi-code-generator` to generate Pydantic base models for the Fivetran API.
More information about code generation can be found [here](https://github.com/koxudaxi/fastapi-code-generator).
Additionally, the project Makefile can be used to generate the models.
